<?php
require_once './dbconnection.php'; 
header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get role from POST request
    $role = isset($_POST['role']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['role'])) : null;

    // Validate that role is either 'user' or 'trainer'
    if ($role != 'user' && $role != 'trainer') {
        $response = array("ResponseCode" => "400", "Result" => "false", "ResponseMsg" => "Invalid role specified.");
        echo json_encode($response);
        exit;
    }

    // Common fields for both users and trainers
    $firstname = isset($_POST['firstname']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['firstname'])) : null;
    $lastname = isset($_POST['lastname']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['lastname'])) : null;
    $email = isset($_POST['email']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['email'])) : null;
    $phone = isset($_POST['phone']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['phone'])) : null;
    $password = isset($_POST['password']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['password'])) : null;

    // Fields specific to 'user' role
    if ($role == 'user') {
        $dateofbirth = isset($_POST['dateofbirth']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['dateofbirth'])) : null;
        $gender = isset($_POST['gender']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['gender'])) : null;
        $bodyweight = isset($_POST['bodyweight']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['bodyweight'])) : null;
        $targetweight = isset($_POST['targetweight']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['targetweight'])) : null;

        // Validation: Ensure all 'user' fields are filled
        if (empty($firstname) || empty($lastname) || empty($email) || empty($phone) || empty($password) || empty($dateofbirth) || empty($gender) || empty($bodyweight) || empty($targetweight)) {
            $response = array("ResponseCode" => "401", "Result" => "false", "ResponseMsg" => "Please fill in all user fields.");
            echo json_encode($response);
            exit;
        }

    }

    // Fields specific to 'trainer' role
    if ($role == 'trainer') {
        $oftenworkout = isset($_POST['oftenworkout']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['oftenworkout'])) : null;
        $length = isset($_POST['length']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['length'])) : null;
        $training = isset($_POST['training']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['training'])) : null;
        $traininglink = isset($_POST['traininglink']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['traininglink'])) : null;
        $testimonials = isset($_POST['testimonials']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['testimonials'])) : null;
        $socialmedia = isset($_POST['socialmedia']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['socialmedia'])) : null;
        $website = isset($_POST['website']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['website'])) : null;
        $commitment = isset($_POST['commitment']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['commitment'])) : null;
        $sponsoredcompany = isset($_POST['sponsoredcompany']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['sponsoredcompany'])) : null;
        $companyname = isset($_POST['companyname']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['companyname'])) : null;
        $crossfitinstructor = isset($_POST['crossfitinstructor']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['crossfitinstructor'])) : null;
        $bobybuilderinstructor = isset($_POST['bobybuilderinstructor']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['bobybuilderinstructor'])) : null;
        $muscleinstructor = isset($_POST['muscleinstructor']) ? strip_tags(mysqli_real_escape_string($conn, $_POST['muscleinstructor'])) : null;

        // Validation: Ensure all 'trainer' fields are filled
        if (empty($firstname) || empty($lastname) || empty($email) || empty($phone) || empty($password) || empty($oftenworkout) || empty($length) || empty($training) || empty($traininglink)) {
            $response = array("ResponseCode" => "401", "Result" => "false", "ResponseMsg" => "Please fill in all trainer fields.");
            echo json_encode($response);
            exit;
        }
    }

    // Profile image handling (common for both roles)
    if (isset($_FILES['profileimage'])) {
        $targetDir = "uploads/";  
        $fileName = basename($_FILES["profileimage"]["name"]);
        $targetFile = $targetDir . $fileName;
        $imageFileType = strtolower(pathinfo($targetFile, PATHINFO_EXTENSION));

        $allowedFileTypes = array("jpg", "jpeg", "png", "gif");
        if (in_array($imageFileType, $allowedFileTypes)) {
            if (move_uploaded_file($_FILES["profileimage"]["tmp_name"], $targetFile)) {
                $profileImageUrl = $targetFile; 
            } else {
                $response = array("ResponseCode" => "401", "Result" => "false", "ResponseMsg" => "Error uploading the image.");
                echo json_encode($response);
                exit;
            }
        } else {
            $response = array("ResponseCode" => "401", "Result" => "false", "ResponseMsg" => "Invalid image type. Only JPG, JPEG, PNG, GIF are allowed.");
            echo json_encode($response);
            exit;
        }
    } else {
        $response = array("ResponseCode" => "401", "Result" => "false", "ResponseMsg" => "Profile image is required.");
        echo json_encode($response);
        exit;
    }

    // Timestamp for creation
    $timestamp = date("Y-m-d H:i:s");

    // Construct the SQL query based on role
    if ($role == 'user') {
        $query = "INSERT INTO register (
            role, firstname, lastname, email, phone, password, dateofbirth, gender, bodyweight, targetweight, profileimage, created_at
        ) VALUES (
            '$role', '$firstname', '$lastname', '$email', '$phone', '$password', '$dateofbirth', '$gender', '$bodyweight', '$targetweight', '$profileImageUrl', '$timestamp'
        )";
    } elseif ($role == 'trainer') {
        $query = "INSERT INTO register (
            role, firstname, lastname, email, phone, password, oftenworkout, length, training, traininglink, testimonials, socialmedia, website,
            commitment, sponsoredcompany, companyname, crossfitinstructor, bobybuilderinstructor, muscleinstructor, profileimage, created_at
        ) VALUES (
            '$role', '$firstname', '$lastname', '$email', '$phone', '$password', '$oftenworkout', '$length', '$training', '$traininglink', '$testimonials', 
            '$socialmedia', '$website', '$commitment', '$sponsoredcompany', '$companyname', '$crossfitinstructor', '$bobybuilderinstructor', 
            '$muscleinstructor', '$profileImageUrl', '$timestamp'
        )";
    }

    // Execute the query
    if (mysqli_query($conn, $query)) {
        $userId = mysqli_insert_id($conn);
        $response = array(
            "ResponseCode" => "200",
            "Result" => "true",
            "ResponseMsg" => "Registration successful!",
            "userid" => $userId 
        );
        echo json_encode($response);
    } else {
        $response = array("ResponseCode" => "500", "Result" => "false", "ResponseMsg" => "Error while inserting data into the database.");
        echo json_encode($response);
    }
} else {
    $response = array("ResponseCode" => "405", "Result" => "false", "ResponseMsg" => "Method not allowed. Only POST requests are allowed.");
    echo json_encode($response);
}
?>
